# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, StrictBool, StrictInt
from typing import Any, ClassVar, Dict, List, Optional
from chat_server_connector_v2.models.ai_assistant_get import AiAssistantGet
from chat_server_connector_v2.models.chat_member_role import ChatMemberRole
from chat_server_connector_v2.models.contact import Contact
from typing import Optional, Set
from typing_extensions import Self
from pydantic_core import to_jsonable_python

class ChatMemberGet(BaseModel):
    """
    ChatMemberGet
    """ # noqa: E501
    role: Optional[ChatMemberRole] = None
    user_id: Optional[StrictInt] = None
    bot_id: Optional[StrictInt] = None
    id: StrictInt
    chat_id: StrictInt
    added_at: StrictInt
    last_seen_at: Optional[StrictInt] = None
    is_removed: Optional[StrictBool] = False
    is_banned: Optional[StrictBool] = False
    is_muted: Optional[StrictBool] = False
    user: Optional[Contact] = None
    bot: Optional[AiAssistantGet] = None
    __properties: ClassVar[List[str]] = ["role", "user_id", "bot_id", "id", "chat_id", "added_at", "last_seen_at", "is_removed", "is_banned", "is_muted", "user", "bot"]

    model_config = ConfigDict(
        validate_by_name=True,
        validate_by_alias=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        return json.dumps(to_jsonable_python(self.to_dict()))

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of ChatMemberGet from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of user
        if self.user:
            _dict['user'] = self.user.to_dict()
        # override the default output from pydantic by calling `to_dict()` of bot
        if self.bot:
            _dict['bot'] = self.bot.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of ChatMemberGet from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "role": obj.get("role"),
            "user_id": obj.get("user_id"),
            "bot_id": obj.get("bot_id"),
            "id": obj.get("id"),
            "chat_id": obj.get("chat_id"),
            "added_at": obj.get("added_at"),
            "last_seen_at": obj.get("last_seen_at"),
            "is_removed": obj.get("is_removed") if obj.get("is_removed") is not None else False,
            "is_banned": obj.get("is_banned") if obj.get("is_banned") is not None else False,
            "is_muted": obj.get("is_muted") if obj.get("is_muted") is not None else False,
            "user": Contact.from_dict(obj["user"]) if obj.get("user") is not None else None,
            "bot": AiAssistantGet.from_dict(obj["bot"]) if obj.get("bot") is not None else None
        })
        return _obj


