# coding: utf-8

"""
    Mentortools Chat API

    Mentortools service for chatting

    The version of the OpenAPI document: 0.1.0
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from chat_server_connector_v2.models.chat_message_insert import ChatMessageInsert

class TestChatMessageInsert(unittest.TestCase):
    """ChatMessageInsert unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> ChatMessageInsert:
        """Test ChatMessageInsert
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `ChatMessageInsert`
        """
        model = ChatMessageInsert()
        if include_optional:
            return ChatMessageInsert(
                text = '',
                file_id = '',
                chat_message_type = 'TEXT',
                attachments = [
                    chat_server_connector_v2.models.chat_message_attachment_create.ChatMessageAttachmentCreate(
                        file_id = '', 
                        attachment_type = 'IMAGE', )
                    ],
                chat_member_id = 56,
                chat_session_id = 56,
                is_hidden = True,
                run_id = ''
            )
        else:
            return ChatMessageInsert(
                chat_member_id = 56,
        )
        """

    def testChatMessageInsert(self):
        """Test ChatMessageInsert"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
